/*
 * Copyright 2013 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Renato Araujo Oliveira Filho <renato@canonical.com>
 */

#ifndef PLUGINMANAGER_H
#define PLUGINMANAGER_H

#include <QObject>
#include <QMap>

#include "chewieplugininterface.h"

class PluginData;

class PluginManager : public QObject
{
    Q_OBJECT
public:
    PluginManager(const QString &baseDir, QObject *parent=0);
    ~PluginManager();

    void setBaseDir(const QString &baseDir);
    QString baseDir() const;

    void load();
    void unload();
    bool isLoaded() const;

    const QList<QString> list() const;
    QVariantMap metaData(const QString &file) const;
    ChewiePluginInterface *instance(const QString &file);
    QObject *objectInstance(const QString &file);
    QString fileName(QObject *plugin) const;

private:
    QString m_baseDir;
    QMap<QString, PluginData* > m_plugins;
    bool m_loaded;
};

#endif
