/*
 * Copyright 2013 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Renato Araujo Oliveira Filho <renato@canonical.com>
 */

#include "config.h"
#include "chewieclient.h"

#include <QQuickView>
#include <QQmlContext>
#include <QQmlEngine>
#include <QDebug>

ChewieClient::ChewieClient(int &argc, char **argv)
    : QObject(0),
      m_view(0),
      m_fullscreen(false)
{
    m_application = new QApplication(argc, argv);
}

ChewieClient::~ChewieClient()
{
    if (m_view != 0) {
        delete m_view;
    }

    delete m_application;
}


void ChewieClient::setupPluginsDir()
{
    m_pluginsDir = CHEWIE_CLIENT_PLUGINS_DIR;

    Q_FOREACH(QString arg, m_application->arguments()) {
        if (arg.startsWith("--plugins-dir=")) {
            QStringList pluginPrefix = arg.split("=");
            if (pluginPrefix.size() == 2) {
                m_pluginsDir = pluginPrefix[1];
            }
        }
    }

    qDebug() << "Loading plugins from: " << m_pluginsDir;
}

void ChewieClient::setupUI()
{
    m_view = new QQuickView;

    Q_FOREACH(QString arg, m_application->arguments()) {
        if (arg.startsWith("--include-dir=")) {
            QStringList includeDir = arg.split("=");
            if (includeDir.size() == 2) {
                m_view->engine()->addImportPath(includeDir[1]);
            }
        } else if (arg.startsWith("--fullscreen")) {
            m_fullscreen = true;
        }
    }
    m_view->rootContext()->setContextProperty("CHEWIEUI_PLUGINS_DIR", m_pluginsDir);

    m_view->setSource(QUrl("qrc:qml/chewieclient.qml"));
    m_view->setResizeMode(QQuickView::SizeRootObjectToView);

    //Usable size on desktop
    m_view->setMinimumSize(QSize(480, 720));
}

void ChewieClient::printUsage() const
{
    QTextStream cout(stdout, QIODevice::WriteOnly);

    cout << "Usage: chewie-client [options] plugin-name" << endl;
    cout << "Options:" << endl;
    cout << " --include-dir=? Dirs to pass to QML as include dir" << endl;
    cout << " --plugins-dir=? Set the base dir used to find plugins" << endl;
    cout << " --fullscreen   Show application in fullscreen" << endl;
}

int ChewieClient::run()
{
    setupPluginsDir();

    if (m_application->arguments().size() >= 2) {
        if (m_application->arguments().contains("--help")) {
            printUsage();
            return 0;
        }
    }

    setupUI();
    if (m_fullscreen) {
        m_view->showFullScreen();
    } else {
       m_view->showMaximized();
    }
    return m_application->exec();
}
