/*
 * Copyright 2013 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Renato Araujo Oliveira Filho <renato@canonical.com>
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import Ubuntu.ChewieUI 0.1 as ChewieUI

Page {
    id: page
    anchors.fill: parent
    title: "Plugin list"

    ChewieUI.PluginModel {
        id: plugins

        baseDir: CHEWIEUI_PLUGINS_DIR
        Component.onCompleted: plugins.load()
    }

    ListView {
        id: mainMenu
        anchors.fill: parent
        model: plugins

        delegate: ChewieUI.Menu {
            anchors.left: parent.left
            anchors.right: parent.right
            height: implicitHeight
            progression: isValid
            objectName: title

            // Used basic components instead of 'ListItem.Standard' properties because it does not support image resize
            Image {
                id: itemIcon
                anchors.left: parent.left
                anchors.verticalCenter: parent.verticalCenter
                source: iconSource
                smooth: true
                width: units.gu(5)
                height: units.gu(5)
            }

            Label {
                anchors.left: itemIcon.right
                anchors.leftMargin: units.gu(0.5)
                anchors.verticalCenter: parent.verticalCenter
                text: (label != "") ? (title + " (" + label + ")") : title
            }

            onClicked: {
                if (progression) {
                    var props = model.initialProperties
                    props["widgetsMap"] = plugins.widgetsMap

                    var page = Qt.createComponent("pluginpage.qml")
                    pages.push(page, {"initialProperties" : props, "component" : model.component})
                }
            }
        }
    }
}

