/*
 * Copyright 2013 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Renato Araujo Oliveira Filho <renato@canonical.com>
 */

#ifndef CHEWIE_COMMONPLUGIN_H
#define CHEWIE_COMMONPLUGIN_H

#include <chewieplugininterface.h>
#include <QObject>

class QDBusActionGroup;
class QDBusMenuModel;
class QStateAction;

class ChewieCommonPlugin : public QObject, public ChewiePluginInterface
{
    Q_OBJECT
    Q_INTERFACES(ChewiePluginInterface)
    Q_PROPERTY(QString title READ title NOTIFY titleChanged)
    Q_PROPERTY(QString label READ label NOTIFY labelChanged)
    Q_PROPERTY(QUrl icon READ icon NOTIFY iconChanged)
    Q_PROPERTY(QString accessibleName READ accessibleName NOTIFY accessibleNameChanged)
    Q_PROPERTY(bool visible READ visible NOTIFY visibleChanged)
    Q_PROPERTY(int priority READ priority NOTIFY priorityChanged)

public:
    ChewieCommonPlugin(QObject *parent = 0);
    ~ChewieCommonPlugin();

    void init(const QJsonObject &config);
    void shutdown();

    QUrl icon() const;
    QString title() const;
    bool visible() const;
    QString accessibleName() const;
    QString label() const;
    int priority() const;

    QQmlComponent *component(QQmlEngine *engine, QObject *parent=0);
    PropertiesMap initialProperties();
    WidgetsMap widgets();

Q_SIGNALS:
    void iconChanged(const QUrl &icon);
    void titleChanged(const QString &title);
    void visibleChanged(bool visible);
    void accessibleNameChanged(const QString &assesibleName);
    void labelChanged(const QString &label);
    void priorityChanged(int priority);

protected:
    PropertiesMap m_initialProperties;

    void setIcon(const QUrl &icon);
    void setTitle(const QString &title);
    void setVisible(bool visible);
    void setAccessibleName(const QString &accessibleName);
    void setLabel(const QString &title);
    void setPriority(int priority);
    virtual bool parseRootElement(const QString &type, QMap<int, QVariant> data);
    virtual QQmlComponent *createComponent(QQmlEngine *engine, QObject *parent=0) const;
    QDBusActionGroup *actionGroup() const;

private Q_SLOTS:
    void onModelChanged();
    void updateState(const QVariant &state);

private:
    QUrl m_icon;
    QString m_title;
    QString m_accessibleName;
    QString m_label;
    bool m_visible;
    int m_priority;
    QDBusMenuModel *m_model;
    QDBusActionGroup *m_actionGroup;
    QStateAction *m_action;
    QQmlComponent *m_component;
};

#endif
