/*
 * Copyright 2013 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Renato Araujo Oliveira Filho <renato@canonical.com>
 *      Ubo Riboni <ugo.riboni@canonical.com>
 */

#include "chewie_datetimeplugin.h"

#include <qdbusmenumodel.h>
#include <qdbusactiongroup.h>
#include <qstateaction.h>
#include <QDateTime>
#include <QDebug>

ChewieDateTimePlugin::ChewieDateTimePlugin(QObject *parent)
    : ChewieCommonPlugin(parent),
      m_action(0)
{
    connect(&m_timer, SIGNAL(timeout()), SLOT(onTimeout()));
}

ChewieDateTimePlugin::~ChewieDateTimePlugin()
{
    if (m_action) {
        delete m_action;
    }
}

void ChewieDateTimePlugin::init(const QJsonObject &config)
{
    ChewieCommonPlugin::init(config);
    m_timer.start(1000 * 10);
}

void ChewieDateTimePlugin::shutdown()
{
    m_timer.stop();
}


QString ChewieDateTimePlugin::dateTime() const
{
    static char timestr[255];
    time_t t;
    struct tm *tmp;

    t = time(NULL);
    tmp = localtime(&t);
    if (tmp == 0) {
        return "";
    }

    int size = strftime(timestr, 255, m_format.toUtf8().data(), tmp);
    if (size == 0) {
        return "";
    }

    return QString::fromLatin1(timestr, size);
}

bool ChewieDateTimePlugin::parseRootElement(const QString &type, QMap<int, QVariant> data)
{
    if (type == "com.canonical.indicator.root.time") {
        if (m_action != 0) {
            delete m_action;
        }

        QVariant action = data[QDBusMenuModel::Action];
        m_action = actionGroup()->action(action.toString());
        if (m_action->isValid()) {
            updateTimeFormat(m_action->state());
        }
        QObject::connect(m_action, SIGNAL(stateChanged(QVariant)), this, SLOT(updateTimeFormat(QVariant)));
        return true;
    } else {
        return false;
    }
}

void ChewieDateTimePlugin::updateTimeFormat(const QVariant &state)
{
    if (state.isValid()) {
        // (sssb) : time format, icon, accessible name format, visible
        QVariantList states = state.toList();
        if (states.size() == 4) {
            m_format = states[0].toString();
            setIcon(QUrl(states[1].toString()));
            setVisible(states[2].toBool());
            setAccessibleName(states[3].toString());
            onTimeout();
        }
    }
}

QQmlComponent *ChewieDateTimePlugin::createComponent(QQmlEngine *engine, QObject *parent) const
{
    return new QQmlComponent(engine, QUrl("qrc:/datetimeplugin/qml/ClockPage.qml"), parent);
}

void ChewieDateTimePlugin::onTimeout()
{
    QString newValue = dateTime();
    setLabel(newValue);
}
