/*
 * Copyright 2012 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Renato Araujo Oliveira Filho <renato@canonical.com>
 */

#include "pluginmodel.h"
#include "test-config.h"
#include "config.h"

#include <QtTest>
#include <QDebug>

class PluginModelTest : public QObject
{
    Q_OBJECT
private Q_SLOTS:
    /*
     * Test if all plugins is loaded correct
     */
    void testLoad()
    {
        PluginModel pm;

        QCOMPARE(pm.baseDir(), QString(CHEWIE_CLIENT_PLUGINS_DIR));
        pm.setBaseDir(TEST_PLUGINS_BASEDIR);
        QCOMPARE(pm.baseDir(), QString(TEST_PLUGINS_BASEDIR));

        QCOMPARE(pm.property("count").toInt(), 0);

        pm.load();

        QCOMPARE(pm.property("count").toInt(), 3);

        pm.unload();

        QCOMPARE(pm.property("count").toInt(), 0);

    }

    /*
     * Test if the plugin data was loaded correct
     */
    void testGet()
    {
        PluginModel pm;
        pm.setBaseDir(TEST_PLUGINS_BASEDIR);
        pm.load();

        QVariantMap data = pm.get(0);
        QCOMPARE(data["title"].toString(), QString("Fake plugin"));
        QCOMPARE(data["label"].toString(), QString("fake label"));
        QCOMPARE(data["iconSource"].value<QUrl>(), QUrl("/usr/share/fake.png"));
        QCOMPARE(data["description"].toString(), QString("Empty plugin for test"));
        // There is no QML context
        QVERIFY(!data["component"].value<QObject*>());
        QCOMPARE(data["isValid"].toBool(), true);

        data = pm.get(1);
        QCOMPARE(data["title"].toString(), QString("Fake2 plugin"));
        QCOMPARE(data["label"].toString(), QString("fake2 label"));
        QCOMPARE(data["iconSource"].value<QUrl>(), QUrl("/usr/share/fake2.png"));
        QCOMPARE(data["description"].toString(), QString("Empty plugin for test2"));
        QCOMPARE(data["isValid"].toBool(), true);

        data = pm.get(3);
        QVERIFY(data.isEmpty());
    }

    /*
     * Test if the plugin was loaded in the correct order (priority)
     */
    void testPriority()
    {
        PluginModel pm;
        pm.setBaseDir(TEST_PLUGINS_BASEDIR);
        pm.load();

        QString desc0 = pm.data(pm.index(0), PluginModel::Description).toString();
        QString desc1 = pm.data(pm.index(1), PluginModel::Description).toString();
        QString desc2 = pm.data(pm.index(2), PluginModel::Description).toString();

        QCOMPARE(desc0, QString("Empty plugin for test"));   // priority = 0
        QCOMPARE(desc1, QString("Empty plugin for test2"));  // priority = 10
        QCOMPARE(desc2, QString("Last plugin in the list")); // priority = 100
    }
};

QTEST_MAIN(PluginModelTest)

#include "pluginmodeltest.moc"
