/*
 * Copyright 2012 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Renato Araujo Oliveira Filho <renato@canonical.com>
 */

#include "fakeplugin.h"

#include <QUrl>
#include <QSettings>
#include <QDebug>

#define CHEWIE_PLUGIN_GROUP "chewie-plugin"

FakePlugin::FakePlugin(QObject *parent)
    : QObject(parent),
      m_initializedCount(0)
{
}

FakePlugin::~FakePlugin()
{
}

void FakePlugin::init(const QJsonObject &config)
{
    QVariantMap info = config.value("MetaData").toVariant().toMap();

    m_initalProperties.clear();
    m_initalProperties.insert("title", info["name"]);
    m_initalProperties.insert("busType", 1);
    m_initalProperties.insert("busName", info["dbus-service"]);
    m_initalProperties.insert("objectPath", info["dbus-object-path"]);

    m_initializedCount++;
}

void FakePlugin::shutdown()
{
    m_initializedCount--;
}


int FakePlugin::initializedCount() const
{
    return m_initializedCount;
}

QUrl FakePlugin::icon() const
{
    return QUrl("/usr/share/fake.png");
}

QString FakePlugin::title() const
{
    return QString("Fake plugin");
}

bool  FakePlugin::visible() const
{
    return true;
}

QString FakePlugin::accessibleName() const
{
    return "";
}

QString FakePlugin::label() const
{
    return "fake label";
}

QQmlComponent *FakePlugin::component(QQmlEngine *engine, QObject *parent)
{
    return 0;
}

int FakePlugin::priority() const
{
    return 0;
}

ChewiePluginInterface::PropertiesMap FakePlugin::initialProperties()
{
    return m_initalProperties;
}

ChewiePluginInterface::WidgetsMap FakePlugin::widgets()
{
    WidgetsMap w;
    w.insert("com.canonical.button", QUrl("Button.qml"));
    w.insert("com.canonical.label", QUrl("Label.qml"));
    return w;
}
